/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2009,2010 by Luigi Ziviani <ziviani_luigi@yahoo.it>.        *
* All Rights Reserved.                                                          *
*********************************************************************************
* Id: mimetypedialog.h,   v 2.7                      2008/01/01                 *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#ifndef MIMETYPEDIALOG_H
#define MIMETYPEDIALOG_H

//! Here is created a new struct consistent with the one(FXFileAssoc) in FXFileDict.h
//! where are defined [FXString names] of icons instead of [*FXIcons]
//! because a subroutine will check for icons names and load images through [FXIconSource].

//! All the other types are preserved to be used with FXFileAssoc function. 
//! The type [command] is used to load the command association with the 
//! [open] option of the filelist pop-up menu.

//! Each entry of the struct in FXFileDict.h goes under the FILETYPES registry section
//! and contents-type will be imported, if they have been created with ControlPanel, 
//! because the present dialog is partially consistent with this program.

struct FileAssociation {
  FXString type;	//! Type Name 
  FXString extension;	//! Full extension name (same of FXFileDict.h)
  FXString command;	//! Command to open the file with (same of FXFileDict.h)
  FXString mimetype;	//! Content-Type [object/format] (same of FXFileDict.h)
  FXString bigname;	//! Name of Big normal icon
  FXString smallname;   //! Name of Small normal icon
  };


class MimeTypeDialog : public FXDialogBox {
  FXDECLARE(MimeTypeDialog)

protected:
  FXIcon 		*darkthemeicon;
  FXIcon 		*shinethemeicon;
  FXIcon 		*classicthemeicon;
  FXIcon 		*gentlethemeicon;
  FXIcon 		*fogthemeicon;
  FXIcon 		*moonthemeicon;
  FXIcon 		*pinkthemeicon;
  FXIcon 		*bloodthemeicon;

  FXIcon		*en_flagicon;
  FXIcon		*it_flagicon;
  FXIcon		*de_flagicon;
  FXIcon		*fr_flagicon;
  FXIcon		*es_flagicon;
  FXIcon		*ru_flagicon;
  FXIcon		*cn_flagicon;
  FXIcon		*jp_flagicon;

  FXButton      *darkthemebutton;
  FXButton      *gentlethemebutton;

  FXButton      *fogthemebutton;
  FXButton      *shinethemebutton;

  FXButton      *bloodthemebutton;
  FXButton      *pinkthemebutton;

  FXButton      *moonthemebutton;
  FXButton      *classicthemebutton;
  FXButton      *sunthemebutton;


  FXButton		*en_button;
  FXButton		*it_button;
  FXButton		*de_button;
  FXButton		*fr_button;
  FXButton		*es_button;
  FXButton		*ru_button;
  FXButton		*cn_button;
  FXButton		*jp_button;

  FXButton		*fontbutton;
  FXButton		*fontbutton2;

  FXIcon        *logoicon;
  FXIcon        *abouticon;
  FXIcon        *conficon;
  FXIcon        *diricon;
  FXIcon 	    *fonticon;
  FXIcon 	    *execicon;
  FXIcon 	    *cancelicon;
  FXIcon 	    *accepticon;

  FXList        *associationlist;
  FXComboBox    *mimetypelist;
  FXButton      *button_bigname;
  FXButton      *button_smallname;
  FXButton      *button_restore;
  FXToolTip     *tooltip;
  FXFont        *titlefont;
  FXFont        *bodyfont;
  FXFont        *menufont;
  FXSpinner		*mousespinner;

  FXColor 		theme_fxmmbase;
  FXColor 		theme_fxmmborder;
  FXColor 		theme_fxmmfore;
  FXColor 		theme_fxmmselfore;
  FXColor 		theme_fxmmmenufore;
  FXColor 		theme_fxmmtipfore;
  FXColor 		theme_fxmmback;
  FXColor 		theme_fxmmselback;
  FXColor 		theme_fxmmmenuback;
  FXColor 		theme_fxmmtipback;
  FXColor 		theme_fxmmhilite;
  FXColor 		theme_fxmmshadow;

  FXint 		fxmmwheellines;

  FXString      theme;
  FXString      language;
  FXString      iconpath;
  FXString      terminal;
  FXString      fontspec;
  FXString      fontspec2;

  FileAssociation   fileassociation;
  FXDataTarget  target_association_type;
  FXDataTarget  target_association_command;
  FXDataTarget  target_association_mimetype;

  FXDataTarget  target_iconpath;
  FXDataTarget  target_terminal;
  FXDataTarget  target_wheel;


  // ffmpegthumbnailer options
  FXint     	thumbnailSize;
  FXint     	imageQuality;
  FXbool    	filmStripOverlay;
  FXbool    	workaroundIssues;
  FXbool    	maintainAspectRatio;
  FXbool    	smartFrameSelection;

  FXDataTarget 	target_thumbnailSize;
  FXDataTarget  target_imageQuality;
  FXDataTarget  target_filmStripOverlay;
  FXDataTarget  target_workaroundIssues;
  FXDataTarget  target_maintainAspectRatio;
  FXDataTarget  target_smartFrameSelection;

  // thumbnails display options
  FXbool		autoThumbnailShow;
  FXbool		autoThumbnailCreate;
  FXbool		autoThumbnailUpdate;

  FXDataTarget  target_autoThumbnailShow;
  FXDataTarget  target_autoThumbnailCreate;
  FXDataTarget  target_autoThumbnailUpdate;

private:
  MimeTypeDialog(){}
  MimeTypeDialog(const MimeTypeDialog&);
  MimeTypeDialog& operator=(const MimeTypeDialog&);

  void saveFileAssociation();
  void saveThemeColors();

public:
  enum {
    ID_CREATE_MIMEASSOCIATION=FXMainWindow::ID_LAST,
    ID_DELETE_MIMEASSOCIATION,
    ID_RENAME_MIMEASSOCIATION,
    ID_SELECT_MIMEASSOCIATION,
    ID_SELECT_ICONPATH,
    ID_SELECT_COMMAND,
    ID_SELECT_MIMETYPE,
    ID_SELECT_ICONBIG_NAME,
    ID_SELECT_ICONSMALL_NAME,
    ID_SELECT_TERMINAL,
    ID_SELECT_FONT,
    ID_SELECT_FONT2,

    ID_SELECT_THEME_DARK,
    ID_SELECT_THEME_GENTLE,
    ID_SELECT_THEME_STORM,
    ID_SELECT_THEME_FOG,
    ID_SELECT_THEME_SHINE,
    ID_SELECT_THEME_SNOW,
    ID_SELECT_THEME_BLOOD,
    ID_SELECT_THEME_RED,
    ID_SELECT_THEME_PINK,
    ID_SELECT_THEME_MOON,
    ID_SELECT_THEME_CLASSIC,
    ID_SELECT_THEME_SUN,

    ID_SELECT_LANGUAGE_EN,
    ID_SELECT_LANGUAGE_IT,
    ID_SELECT_LANGUAGE_DE,
    ID_SELECT_LANGUAGE_FR,
    ID_SELECT_LANGUAGE_ES,
    ID_SELECT_LANGUAGE_RU,
    ID_SELECT_LANGUAGE_CN,
    ID_SELECT_LANGUAGE_JP,

    ID_RESTORE_SETTINGS,
    ID_FXMMAPPLICATION,
    };

public:
  long onCmdFileAssociation(FXObject*,FXSelector,void*);
  long onCmdCreateFileAssociation(FXObject*,FXSelector,void*);
  long onCmdDeleteFileAssociation(FXObject*,FXSelector,void*);
  long onCmdRenameFileAssociation(FXObject*,FXSelector,void*);

  long onCmdSelectThemeColors(FXObject*,FXSelector,void*);
  long onCmdSelectLanguage(FXObject*,FXSelector,void*);
  long onCmdSelectTerminal(FXObject*,FXSelector,void*);
  long onCmdSelectMimeType(FXObject*,FXSelector,void*);
  long onCmdSelectIconPath(FXObject*,FXSelector,void*);
  long onCmdSelectCommand(FXObject*,FXSelector,void*);
  long onCmdSelectIcon(FXObject*,FXSelector,void*);
  long onCmdSelectFont(FXObject*,FXSelector,void*);
  long onCmdSelectFont2(FXObject*,FXSelector,void*);
  long onCmdCloseDialog(FXObject*,FXSelector,void*);
  long onCmdRestoreDefaults(FXObject*,FXSelector,void*);

public:
  // Constructor
  MimeTypeDialog(FXWindow *owner);
  virtual ~MimeTypeDialog();
  };

#endif
